import pandas as pd
import re

# Function to convert string with K/M suffix to numeric value
def convert_to_numeric(value_str):
    if value_str == 'Like':
        return 0
    
    multiplier = 1
    if value_str.endswith('K'):
        multiplier = 1000
    elif value_str.endswith('M'):
        multiplier = 1000000
    
    # Use try-except to handle AttributeError
    try:
        # Use re.search to find the numeric part
        match = re.search(r'\d+\.*\d*', value_str)
        if match:
            numeric_part = float(match.group())
            return int(numeric_part * multiplier)
        else:
            # Handle cases where no match is found (e.g., pure numeric values)
            return int(value_str)
    except AttributeError:
        # Handle AttributeError (e.g., when value_str is None or not string-like)
        return None


def clean_youtube_csv(fname):
    df = pd.read_csv(fname)
    df = df.drop(columns=["ID", "DESCRIPTION", "STATUS", "KEYWORDS", 
                          "VIDIQ SCORE", "DESC LINK COUNT", "DESC WORD COUNT", 
                          "CREATOR SUGGESTED", "ENGAGEMENT RATE"])
    # make likes and comments numeric:
    df['likes_numeric'] = df['YT LIKES'].apply(convert_to_numeric)
    df['comments_numeric'] = df['YT COMMENTS'].apply(convert_to_numeric)
    df = df.drop(columns=["YT LIKES", "YT COMMENTS"])
    # kick out videos without likes and comments:
    df = df[df['likes_numeric'] != 0]
    df = df[df['comments_numeric'] != 0]
    # introduce views/like & comments/like:
    df['views_per_like'] = (df['VIEWS'] / df['likes_numeric']).round(1)
    df['views_per_comment'] = (df['VIEWS'] / df['comments_numeric']).round(1)
    df = df.sort_values(by='views_per_like', ascending=True)
    # delete all videos with less than average view count
    average_views = df['VIEWS'].mean().round()
    print(f"Average views = {average_views}")
    df = df[df['VIEWS'] >= average_views]
    # convert integer columns to float for better formatting
    df['VIEWS'] = df['VIEWS'].astype(float)
    df['likes_numeric'] = df['likes_numeric'].astype(float)
    df['comments_numeric'] = df['comments_numeric'].astype(float)

    return df

def pandas_set_defaults():
    pd.set_option('display.float_format', '{:,.0f}'.format)
    pd.set_option('display.max_colwidth', 50) # set to default
    pd.set_option('display.max_rows', 60) # set to default

def pandas_view_all():
    # Format output:
    pd.set_option('display.max_colwidth', None) # To show the full title
    pd.set_option('display.max_rows', None)